@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # User Authentication Module
 #
-# $Id: lonauth.pm,v 1.92 2008/05/30 19:09:50 bisitz Exp $
+# $Id: lonauth.pm,v 1.94 2008/07/13 00:51:31 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -212,6 +212,7 @@ sub handler {
     my $role   = $r->dir_config('lonRole');
     my $domain = $r->dir_config('lonDefDomain');
     my $prodir = $r->dir_config('lonUsersDir');
+    my $contact_name = &mt('LON-CAPA helpdesk');
 
 # ---------------------------------------- Get the information from login token
 
@@ -230,6 +231,10 @@ sub handler {
 	    return OK;
 	}
     }
+    if (!&Apache::lonnet::domain($form{'udom'})) {
+        &failed($r,'The domain you provided is not a valid LON-CAPA domain.',\%form);
+        return OK;
+    }
     my ($key,$firsturl)=split(/&/,$tmpinfo);
 
     my $keybin=pack("H16",$key);
@@ -287,19 +292,21 @@ sub handler {
                 &Apache::loncommon::start_page('Create a user account in LON-CAPA',
                                                '',{'no_inline_link'   => 1,});
             my $domdesc = &Apache::lonnet::domain($form{'udom'},'description');
-            my ($output,$checkfail) = &Apache::createaccount::username_check($form{'uname'},
-                                                                  $form{'udom'},$domdesc);
+            my $lonhost = $r->dir_config('lonHostID');
+            my $origmail = $Apache::lonnet::perlvar{'lonSupportEMail'};
+            my $contacts = 
+                &Apache::loncommon::build_recipient_list(undef,'helpdeskmail',
+                                                        $form{'udom'},$origmail);
+            my ($contact_email) = split(',',$contacts); 
+            my $output = &Apache::createaccount::username_check($form{'uname'}, 
+                                                                $form{'udom'},$domdesc,'',
+                                                                $lonhost,$contact_email,$contact_name);
             &Apache::loncommon::content_type($r,'text/html');
             $r->send_http_header;
             &Apache::createaccount::print_header($r,$start_page);
-            my $msg = '<h4>'.&mt('Although your username and password were authenticated, you do not currently have a LON-CAPA account in this domain.').'<br />';
-            if ($checkfail) {
-                $msg .= &mt('A LON-CAPA account may not be created with the username you used.');
-            } else {
-                $msg .= &mt('To create one, use the table below to provide information about yourself (if appropriate), then click the "Create LON-CAPA account" button.');
-            }
-            $r->print('<h4>'.$msg.'</h4>'.$output);
-            $r->print(&Apache::loncommon::end_page());
+            $r->print('<h3>'.&mt('Account creation').'</h3>'.
+                      &mt('Although your username and password were authenticated, you do not currently have a LON-CAPA account at this institution.').'<br />'.
+                      $output.&Apache::loncommon::end_page());
             return OK;
         } else {
             &failed($r,'Although your username and password were authenticated, you do not currently have a LON-CAPA account in this domain, and you are not permitted to create one.',\%form);
