@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Starts a user off based of an existing token.
 #
-# $Id: migrateuser.pm,v 1.12 2007/10/01 21:52:50 albertel Exp $
+# $Id: migrateuser.pm,v 1.13 2008/03/24 04:56:07 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -67,6 +67,9 @@ sub handler {
     
     &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['token']);
     my %data =   &Apache::lonnet::tmpget($env{'form.token'});
+    if (keys(%data) == 0) {
+        return &goto_login($r);
+    }
     my $delete = &Apache::lonnet::tmpdel($env{'form.token'});
 
     &Apache::lonlocal::get_language_handle($r);
