@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # caparesponse definition
 #
-# $Id: caparesponse.pm,v 1.226 2008/06/10 15:22:39 www Exp $
+# $Id: caparesponse.pm,v 1.227 2008/07/26 15:06:43 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -311,8 +311,7 @@ sub start_numericalresponse {
 	    if ($unit =~ /\S/) { $result.=" (in $unit) "; }
 	}
         if (($token->[1] eq 'formularesponse') && 
-            ($Apache::inputtags::status['-1'] eq 'CAN_ANSWER') &&
-            (!&Apache::lonxml::get_param_var('samples',$parstack,$safeeval))) {
+            ($Apache::inputtags::status['-1'] eq 'CAN_ANSWER')) {
             $result.=&edit_formula_button($id,"HWVAL_$id");
         }
 	if (  &Apache::response::show_answer() ) {
