@@ -2,7 +2,7 @@
 # The LearningOnline Network with CAPA
 # image click response style
 #
-# $Id: imageresponse.pm,v 1.93 2008/03/12 02:46:53 raeburn Exp $
+# $Id: imageresponse.pm,v 1.94 2008/08/08 16:37:13 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -367,7 +367,7 @@ sub gradefoils {
 		} elsif ($1 eq 'polygon') {
 		    $grade=&grade_polygon($area,$x,$y);
 		} else {
-		    &Apache::lonxml::error("Unknown area style $area");
+		    &Apache::lonxml::error(&mt('Unknown area style [_1]',$area));
 		}
 		&Apache::lonxml::debug("Area said $grade");
 		if ($grade eq 'APPROX_ANS') { last; }
@@ -494,11 +494,12 @@ sub start_foil {
 	$target eq 'analyze' || $target eq 'answer') {
 	my $name = &Apache::lonxml::get_param('name',$parstack,$safeeval);
 	if ($name eq "") {
-	    &Apache::lonxml::warning("Foils without names exist. This can cause problems to malfunction.");
+	    &Apache::lonxml::warning(&mt('Foils without names exist. This can cause problems to malfunction.'));
 	    $name=$Apache::lonxml::curdepth;
 	}
 	if (defined($Apache::response::foilnames{$name})) {
-	    &Apache::lonxml::error(&mt("Foil name <b><tt>[_1]</tt></b> appears more than once. Foil names need to be unique.",$name));
+	    &Apache::lonxml::error(&mt("Foil name [_1] appears more than once. Foil names need to be unique."
+                                      ,'<b><tt>'.$name.'</tt></b>'));
 	}
 	$Apache::response::foilnames{$name}++;
 	if ( $Apache::imageresponse::conceptgroup
