@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.244 2008/07/26 19:11:23 raeburn Exp $
+# $Id: inputtags.pm,v 1.245 2008/09/01 10:01:57 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -729,7 +729,10 @@ sub decideoutput {
 	$css_class=$possible_class{'not_charged_try'};
 	$button = 1;
     } elsif ($award eq 'MISSING_ANSWER') {
-	$message = &mt('Some items were not submitted.').&Apache::loncommon::help_open_topic('Some_Items_Were_Not_Submitted');
+	$message = &mt('Some items were not submitted.');
+        if ($target ne 'tex') {
+           $message .= &Apache::loncommon::help_open_topic('Some_Items_Were_Not_Submitted');
+        }
 	$css_class=$possible_class{'not_charged_try'};
 	$button = 1;
     } elsif ($award eq 'ERROR') {
