@@ -1,7 +1,7 @@
 # LearningOnline Network with CAPA
 # option list style responses
 #
-# $Id: optionresponse.pm,v 1.150 2008/06/23 11:27:44 bisitz Exp $
+# $Id: optionresponse.pm,v 1.151 2008/08/08 16:37:13 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -684,12 +684,12 @@ sub end_foil {
       my $name = &Apache::lonxml::get_param('name',$parstack,$safeeval);
       &Apache::lonxml::debug("Got a name of :$name:");
       if ($name eq "") {
-	  &Apache::lonxml::warning("Foils without names exist. This can cause problems to malfunction.");
+	  &Apache::lonxml::warning(&mt('Foils without names exist. This can cause problems to malfunction.'));
 	  $name=$Apache::lonxml::curdepth;
       }
       &Apache::lonxml::debug("Using a name of :$name:");
       if (defined($Apache::response::foilnames{$name})) {
-	  &Apache::lonxml::error(&mt("Foil name <b><tt>[_1]</tt></b> appears more than once. Foil names need to be unique.",$name));
+	  &Apache::lonxml::error(&mt("Foil name [_1] appears more than once. Foil names need to be unique.",'<b><tt>'.$name.'</tt></b>'));
       }
       $Apache::response::foilnames{$name}++;
       my $location =&Apache::lonxml::get_param('location',$parstack,$safeeval);
