@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # mutliple choice style responses
 #
-# $Id: radiobuttonresponse.pm,v 1.133 2008/03/22 00:36:57 raeburn Exp $
+# $Id: radiobuttonresponse.pm,v 1.134 2008/08/08 16:37:13 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -442,7 +442,7 @@ sub whichfoils {
 	    }
 	}
 	if (!$havetrue && $Apache::lonhomework::type ne 'survey') {
-	    &Apache::lonxml::error("There are no true statements available.<br />");
+	    &Apache::lonxml::error(&mt('There are no true statements available.').'<br />');
 	}
     } else {
 	my $current=0;
@@ -503,7 +503,7 @@ sub whichfoils {
 	my $dosplice=1;
 	if ($notrue && $Apache::lonhomework::type ne 'survey') {
 	    $dosplice=0;
-	    &Apache::lonxml::error("There are no true statements available.<br />");
+	    &Apache::lonxml::error(&mt('There are no true statements available.').'<br />');
 	}
 	#insert the true statement, keeping track of where it wants to be
 	if ($Apache::response::foilgroup{$truename.'.location'} eq 'top' && $dosplice) {
@@ -764,11 +764,11 @@ sub end_foil {
 	if ($value ne 'unused') {
 	    my $name = &Apache::lonxml::get_param('name',$parstack,$safeeval);
 	    if ($name eq "") {
-		&Apache::lonxml::warning("Foils without names exist. This can cause problems to malfunction.");
+		&Apache::lonxml::warning(&mt('Foils without names exist. This can cause problems to malfunction.'));
 		$name=$Apache::lonxml::curdepth;
 	    }
 	    if (defined($Apache::response::foilnames{$name})) {
-		&Apache::lonxml::error(&mt("Foil name <b><tt>[_1]</tt></b> appears more than once. Foil names need to be unique.",$name));
+		&Apache::lonxml::error(&mt('Foil name [_1] appears more than once. Foil names need to be unique.','<b><tt>'.$name.'</tt></b>'));
 	    }
 	    $Apache::response::foilnames{$name}++;
 	    my $location =&Apache::lonxml::get_param('location',$parstack,
