@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # various response type definitons response definition
 #
-# $Id: response.pm,v 1.187 2008/02/01 22:05:45 raeburn Exp $
+# $Id: response.pm,v 1.193 2008/06/14 20:16:57 www Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -486,6 +486,10 @@ sub start_mathresponse {
 						   $safeeval);
 	    $Apache::inputtags::answertxt{$id}=[$answer];
 	}
+        if ($Apache::inputtags::status['-1'] eq 'CAN_ANSWER') {
+            $result.=&edit_mathresponse_button($id,"HWVAL_$id");
+        }
+
     } elsif ($target eq 'edit') {
 	$result.=&Apache::edit::tag_start($target,$token);
 	$result.=&Apache::edit::text_arg('String to display for answer:',
@@ -495,12 +499,16 @@ sub start_mathresponse {
 					   ['maxima'],
 					   $token);
 	$result.=&Apache::edit::text_arg('Argument Array:',
-					 'args',$token);
+					 'args',$token).
+                 &Apache::loncommon::help_open_topic('Maxima_Argument_Array');
+        $result.=&Apache::edit::text_arg('Libraries:',
+                                         'libraries',$token).
+                 &Apache::loncommon::help_open_topic('Maxima_Libraries');
 	$result.=&Apache::edit::end_row().&Apache::edit::start_spanning_row();
     } elsif ($target eq 'modified') {
 	my $constructtag;
 	$constructtag=&Apache::edit::get_new_args($token,$parstack,
-						  $safeeval,'answerdisplay','cas','args');
+						  $safeeval,'answerdisplay','cas','args','libraries');
 	if ($constructtag) {
 	    $result = &Apache::edit::rebuild_tag($token);
 	}
@@ -512,6 +520,21 @@ sub start_mathresponse {
     return $result;
 }
 
+sub edit_mathresponse_button {
+    my ($id,$field)=@_;
+    my $button=&mt('Edit Answer');
+    return(<<ENDFORMULABUTTON);
+<script language="JavaScript">
+function edit_${id}_${field} (textarea) {
+    thenumber = textarea;
+    thedata = document.forms['lonhomework'].elements[textarea].value;
+    newwin = window.open("/adm/dragmath/applet/MaximaPopup.html","","width=565,height=400,resizable");
+}
+</script>
+<input type='button' value='$button' onclick="javascript:edit_${id}_${field}('${field}');void(0);" />
+ENDFORMULABUTTON
+}
+
 sub end_mathresponse {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval)=@_;
     my $result;
@@ -532,7 +555,8 @@ sub end_mathresponse {
 	    my $cas = &Apache::lonxml::get_param('cas',$parstack,$safeeval);
             if ($cas eq 'maxima') {
                 my $args = [&Apache::lonxml::get_param_var('args',$parstack,$safeeval)];
-                $award=&Apache::lonmaxima::maxima_run($Apache::response::custom_answer[-1],$response,$args);
+                $award=&Apache::lonmaxima::maxima_run($Apache::response::custom_answer[-1],$response,$args,
+                                                      &Apache::lonxml::get_param('libraries',$parstack,$safeeval));
             }
 	    if (!&Apache::inputtags::valid_award($award)) {
 		$error = $award;
@@ -801,9 +825,13 @@ sub answer_part {
 		    last;
 		}
 	    }
-	    if ($answer ne '') {
-		$answer = '\verb'.$to_use.$answer.$to_use;
-	    }
+            my $fullanswer=$answer;
+            $answer='';
+            foreach my $element (split(/[\;]/,$fullanswer)) {
+	       if ($element ne '') {
+	 	  $answer.= '\verb'.$to_use.$element.$to_use.' \newline';
+	       }
+            }
 	}
 	if ($answer ne '') {
 	    push(@answer_bits,$answer);
@@ -822,10 +850,12 @@ sub answer_footer {
     my ($type) = @_;
     my $result;
     if ($env{'form.answer_output_mode'} eq 'tex') {
-	my $columns = scalar(@answer_bits);
-	$result  = ' \vskip 0 mm \noindent \begin{tabular}{|'.'c|'x$columns.'}\hline ';
-	$result .= join(' & ',@answer_bits);
-	$result .= ' \\\\ \\hline \end{tabular} \vskip 0 mm ';
+	$result  = ' \vskip 0 mm \noindent \begin{tabular}{|p{1.5cm}|p{6.8cm}|}\hline ';
+	$result .= $answer_bits[0].'&\vspace*{-4mm}\begin{itemize}';
+        for (my $i=1;$i<=$#answer_bits;$i++) {
+            $result.='\item '.$answer_bits[$i].'\vspace*{-7mm}';
+        }
+	$result .= ' \end{itemize} \\\\ \hline \end{tabular} \vskip 0 mm ';
     } else {
 	if (!$need_row_start) {
 	    $result .= '</tr>';
