@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.425 2008/07/28 05:26:00 raeburn Exp $
+# $Id: structuretags.pm,v 1.429 2008/08/26 03:18:29 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -416,8 +416,9 @@ sub problem_web_to_edit_header {
 <select name='problemtype'>
   <option value=''></option>
   ".&option('exam'   ,'problemtype').&mt("Exam Problem")."</option>
-  ".&option('problem','problemtype').&mt("Homework problem")."</option>
+  ".&option('problem','problemtype').&mt("Homework Problem")."</option>
   ".&option('survey' ,'problemtype').&mt("Survey Question")."</option>
+  ".&option('practice' ,'problemtype').&mt("Practice Problem")."</option>
 </select>
 </span>
 $show_all
@@ -865,8 +866,7 @@ sub start_problem {
 		    '</label>';
 	    }
             if ($Apache::lonhomework::type eq 'practice') {
-               $form_tag_start.='<span class="LC_info"><h3>'.&mt('Practice Problem').'</h3></span>'.
-                                '<span class="LC_info">'.&mt('Submissions are not permanently recorded').'</span>';
+                $form_tag_start.=&practice_problem_header();
             }
 	    $form_tag_start.='<hr />';
 	}
@@ -940,6 +940,11 @@ sub start_problem {
 	    # create a page header and exit
 	    if ($env{'request.state'} eq "construct") {
 		$result.= &problem_web_to_edit_header($env{'form.rndseed'});
+                if ($Apache::lonhomework::type eq 'practice') {
+                    $result.= '<input type="submit" name="resetdata" '.
+                              'value="'.&mt('New Problem Variation').'" />'.
+                              &practice_problem_header().'<hr />';
+                }
 	    }
 	    # if we are viewing someone else preserve that info
 	    if (defined $env{'form.grade_symb'}) {
@@ -1175,6 +1180,11 @@ sub start_library {
 	$result.=" \n $form_tag_start".	
 		  '<input type="hidden" name="submitted" value="yes" />';
 	$result.=&problem_web_to_edit_header($rndseed);
+        if ($Apache::lonhomework::type eq 'practice') {
+            $result.= '<input type="submit" name="resetdata" '.
+                      'value="'.&mt('New Problem Variation').'" />'.
+                      &practice_problem_header().'<hr />';
+        }
     }
     return $result;
 }
@@ -1382,7 +1392,11 @@ sub end_languageblock {
 	    my $result = &Apache::lonxml::endredirection();
 	    my $which = &Apache::lonxml::get_param('which',$parstack,
 						   $safeeval);
-	    $available_texts{$which} = $result;
+            foreach my $language (split(/\s*\,\s*/,$which)) {
+               unless ($language=~/\w/) { next; }
+               $available_texts{$language} = $result;
+            }
+
 	}
 	return '';
     }
@@ -1839,7 +1853,8 @@ sub start_problemtype {
 	$result .=&Apache::edit::checked_arg('When used as type(s):','for',
 					     [ ['exam','Exam/Quiz Problem'],
 					       ['survey','Survey'],
-					       ['problem','Homework Problem'] ]
+					       ['problem','Homework Problem'],
+                                               ['practice','Practice Problem'] ]
 					     ,$token);
 	$result .=&Apache::edit::end_row().&Apache::edit::start_spanning_row();
     } elsif ($target eq 'modified') {
@@ -1872,21 +1887,20 @@ sub end_startouttext {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $result='';
     my $text='';
-
     if ($target eq 'edit') {
 	my $areaid = 'homework_edit_'.$Apache::lonxml::curdepth;
 	$text=&Apache::lonxml::get_all_text("endouttext",$parser,$style);
 	$result.=&Apache::edit::start_table($token)."<tr><td>".&mt('Text Block')."</td>
 <td>".&mt('Delete:').
                  &Apache::edit::deletelist($target,$token)
-		 ."</td>
-<td>".
-                 &Apache::edit::insertlist($target,$token).
-		 '</td>';
+		 ."</td>";
         unless ($env{'environment.wysiwygeditor'} eq 'on') {
             $result.='<td align="left">'
                      .&Apache::lonhtmlcommon::dragmath_button($areaid,1)
-                     .'</td>';
+		     .'</td>'
+                     .'<td>'
+                     .&Apache::edit::insertlist($target,$token)
+		     .'</td>';
         }
 	$result.='<td align="right" valign="top">' .
 		 &Apache::loncommon::helpLatexCheatsheet().
@@ -1963,5 +1977,11 @@ sub end_simpleeditbutton {
     return '';
 }
 
+sub practice_problem_header {
+    return '<span class="LC_info"><h3>'.&mt('Practice Problem').'</h3></span>'.
+           '<span class="LC_info">'.&mt('Submissions are not permanently recorded').
+           '</span>';
+}
+
 1;
 __END__
