@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for displaying the course catalog interface
 #
-# $Id: coursecatalog.pm,v 1.37 2008/07/08 09:23:38 raeburn Exp $
+# $Id: coursecatalog.pm,v 1.41 2008/07/17 12:00:28 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -53,7 +53,8 @@ sub handler {
     }
     &Apache::lonacc::get_posted_cgi($r);
     &Apache::lonlocal::get_language_handle($r);
-    &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},['sortby']);
+    &Apache::loncommon::get_unprocessed_cgi($ENV{'QUERY_STRING'},
+                                            ['sortby','showdom']);
 
     my $codedom = &Apache::lonnet::default_login_domain();
 
@@ -105,12 +106,14 @@ function changeSort(caller) {
     document.$formname.sortby.value = caller;
     document.$formname.submit();
 }
+
 function setCourseId(caller) {
     document.$formname.coursenum.value = caller;
     document.$formname.submit();
 }
 
 ENDSCRIPT
+        $catjs .= &courselink_javascript(); 
         my $numtitles;
         if ($env{'form.currcat_0'} eq 'instcode::0') {
             $numtitles = &instcode_course_selector($r,$codedom,$formname,$domdesc,
@@ -154,8 +157,10 @@ sub course_details {
     my $output;
     my %add_entries = (topmargin    => "0",
                        marginheight => "0",);
+    my $js = '<script type="text/javascript">'."\n".
+             &courselink_javascript().'</script>'."\n";
     my $start_page =
-        &Apache::loncommon::start_page('Course Catalog','',
+        &Apache::loncommon::start_page('Course Catalog',$js,
                                            {
                                              'add_entries' => \%add_entries,
                                              'no_inline_link'   => 1,});
@@ -171,16 +176,43 @@ sub course_details {
              {text=>"Course details"});
     $r->print(&Apache::lonhtmlcommon::breadcrumbs('Course Details'));
     $r->print('<br />'.&mt('Detailed course information:').'<br /><br />'.
-              '<form name="'.$formname.'" method="post">'.
               &print_course_listing($codedom,undef,$trails,$allitems).
               '<br /><br />');
-    $r->print('<a href = "javascript:document.coursecatalog.submit()">'.
+    $r->print('<form name="'.$formname.'" method="post" action="/adm/coursecatalog">'.
+              '<a href = "javascript:document.coursecatalog.submit()">'.
               &mt('Back to course listing').'</a>'.
-              '<input type="hidden" name="sortby" value="'.
-              $env{'form.sortby'}.'" />'.
-              '<input type="hidden" name="state" value="listing" /></form>');
+              &Apache::lonhtmlcommon::echo_form_input(['coursenum','catalogfilter',
+                                                       'showdetails','courseid']).'</form>');
+    return;
 }
 
+sub courselink_javascript {
+    return <<"END";
+
+function ToSyllabus(cdom,cnum) {
+    if (cdom == '' || cdom == null) {
+        return;
+    }
+    if (cnum == '' || cnum == null) {
+        return;
+    }
+    document.linklaunch.action = "/public/"+cdom+"/"+cnum+"/syllabus";
+    document.linklaunch.submit();
+}
+
+function ToSelfenroll(courseid) {
+    if (courseid == '') {
+        return;
+    }
+    document.linklaunch.action = "/adm/selfenroll";
+    document.linklaunch.courseid.value = courseid;
+    document.linklaunch.submit();
+}
+
+END
+}
+
+
 sub instcode_course_selector {
     my ($r,$codedom,$formname,$domdesc,$catlinks,$catjs) = @_;
     my %coursecodes = ();
@@ -487,8 +519,8 @@ sub additional_filters {
             $output .= '<tr><td><label>'.
                        '<input type="checkbox" name="withsubcats" value="1" '.
                        $include_subcat_status.'/>'.
-                       &mt('Include subcategories within "[_1]"',$catname).
-                       '</label></td></tr>';
+                       &mt('Include subcategories within "[_1]"',
+                           &unescape($catname)).'</label></td></tr>';
         }
     }
     my $show_selfenroll_status;
@@ -733,9 +765,10 @@ sub print_course_listing {
     my %domconfig =
         &Apache::lonnet::get_dom('configuration',['usercreation'],$domain);
     $output .= &construct_data_table($knownuser,\%courses,$details,undef,$now,\%domconfig,$trails,$allitems);
-    if ($env{'form.coursenum'} ne '') {
-        $output .= &Apache::lonhtmlcommon::echo_form_input(['coursenum','state','catalogfilter','sortby','showdetails']);
-    }
+    $output .= "\n".'<form name="linklaunch" method="post" action="">'.
+               '<input type="hidden" name="backto" value="coursecatalog" />'.
+               '<input type="hidden" name="courseid" value="" />'.
+               &Apache::lonhtmlcommon::echo_form_input(['catalogfilter','courseid']).'</form>';
     return $output;
 }
 
@@ -836,7 +869,7 @@ sub build_courseinfo_hash {
         $cleandesc=~s/'/\\'/g;
         $cleandesc =~ s/^\s+//;
         my ($cdom,$cnum)=split(/\_/,$course);
-        my ($descr,$instcode,$singleowner,$ttype,$selfenroll_types,
+        my ($instcode,$singleowner,$ttype,$selfenroll_types,
             $selfenroll_start,$selfenroll_end,@owners,%ownernames,$categories);
         if (ref($courses->{$course}) eq 'HASH') {
             $descr = $courses->{$course}{'description'};
@@ -1038,7 +1071,7 @@ sub courseinfo_row {
                '<td>'.$xlist_items.'</td>'.
                '<td>'.$title.'&nbsp;<font size="-2">';
     if ($showsyllabus) {
-        $output .= &Apache::loncommon::syllabuswrapper(&mt('Syllabus'),$cnum,$cdom);
+        $output .= '<a href="javascript:ToSyllabus('."'$cdom','$cnum'".')">'.&mt('Syllabus').'</a>';
     } else {
         $output .= '&nbsp;';
     }
@@ -1062,7 +1095,7 @@ sub courseinfo_row {
             if (($info->{'selfenroll_start'} > 0) && ($info->{'selfenroll_start'} > $now)) {
                 $output .= '<td>'.&mt('Starts: [_1]','<span class="LC_cusr_emph">'.$showstart.'</span>').'<br />'.&mt('Ends: [_1]','<span class="LC_cusr_emph">'.$showend.'</span>').'</td>';
             } else { 
-                $output .= '<td><a href="/adm/selfenroll?cid='.$course.'">'.&mt('Enroll in course').'</a></td>';
+                $output .= '<td><a href="javascript:ToSelfenroll('."'$course'".')">'.&mt('Enroll in course').'</a></td>';
             }
             $selfenroll = 1;
         }
@@ -1092,7 +1125,7 @@ sub identify_sections {
         }
     }
     @secnums = sort {$a <=> $b} @secnums;
-    my $seclist = join(', ',@secnums);
+    $seclist = join(', ',@secnums);
     my $numsec = @secnums;
     return ($seclist,$numsec);
 }
