@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Internal Server Error Handler
 #
-# $Id: lonerrorhandler.pm,v 1.14 2007/12/04 04:43:21 raeburn Exp $
+# $Id: lonerrorhandler.pm,v 1.15 2008/08/19 11:22:00 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -89,9 +89,11 @@ ENDMESSAGE
 	    $r->print('<h2>'.&mt('Report submitted').'</h2>'.&mt('Thank you!'));
         } else {
             $r->print('<h2>'.&mt('Warning: Report not submitted').'</h2>'.
-                      '<span class="LC_error">'.&mt("The administrators of
-                      the domain ($defdom) have not set any e-mail addresses
-                      for receipt of your error report.").'</span>');
+                      '<span class="LC_error">'
+                     .&mt('The administrators of the domain [_1] have not set'
+                         .' any e-mail addresses for receipt of your error report.'
+                         ,'<tt>'.$defdom.'</tt>')
+                     .'</span>');
         }
     } else {
 # ------------------------------------------------------------- Get environment
@@ -114,13 +116,15 @@ ENDMESSAGE
 	my $version=$r->dir_config('lonVersion');
 
 # ----------------------------------------------------------- Print error form
-	$r->print('<h2>'.
-&mt('Somewhere something went wrong - please help us to find out what.').'</h2>'.
-&mt('Please take a moment to fill out the form below.').' '.&mt('Your information,
- together with internal debugging information, will be emailed to the system and 
-server administrators.').'
+	$r->print('<h2 class="LC_error">'
+.&mt('Somewhere something went wrong')
+.'</h2>'
+.'<p>'.&mt('Please help us to find out what.').'</p>'
+.'<p>'.&mt('Please take a moment to fill out the form below.').' '
+.&mt('Your information, together with internal debugging information, '
+    .'will be emailed to the system and server administrators.')
+.'</p>
 <form action="/adm/errorhandler" method="post">
-<input type="submit" value="'.&mt('Send Information').'" />
 <h3>'.&mt('Please describe what you did just before this screen came up').'</h3>
 <textarea name="prioraction" cols="50" rows="5">
 </textarea>
@@ -140,12 +144,12 @@ server administrators.').'
 </p>
 </form>
 <h1>'.&mt('Thank you for your help!').'</h1>
-<font size="-1">
-<pre>
+<div><font size="-1">
 '.&mt('Internal info:').
+'<pre>'.
 $syllabus.'
 </pre>
-</font>
+</font></div>
 ');
 # -------------------------- Better terminate this in case something was sticky
 
