@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.177 2008/07/28 05:25:59 raeburn Exp $
+# $Id: lonhtmlcommon.pm,v 1.179 2008/08/24 12:56:28 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -84,8 +84,9 @@ sub dragmath_button {
     if ($helpicon) {
         $help_text = &Apache::loncommon::help_open_topic('Authoring_Math_Editor');
     }
+    my $buttontext=&mt('Edit Math');
     return <<ENDDRAGMATH;
-                <input type="button" value="Edit Math", onclick="javascript:mathedit('$textarea',document)" />$help_text
+                <input type="button" value="$buttontext", onclick="javascript:mathedit('$textarea',document)" />$help_text
 ENDDRAGMATH
 }
 
@@ -1724,6 +1725,25 @@ sub course_custom_roles {
 }
 
 
+##############################################
+##############################################
+
+# topic_bar
+#
+# Generates a div containing a numbered (static image) followed by a title
+# with a background color defined in the corresponding CSS: LC_topic_bar
+#
+sub topic_bar {
+    my ($imgnum,$title) = @_;
+    return '
+<div class="LC_topic_bar">
+    <img alt="'.&mt('Step [_1]',$imgnum).
+              '"src="/res/adm/pages/bl_step'.$imgnum.'.gif" />&nbsp;
+    <span>'.$title.'</span>
+</div>
+';
+}
+
 ##############################################
 ##############################################
                                                                              
