@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a course
 #
-# $Id: lonpickcourse.pm,v 1.67.2.3 2008/01/20 22:47:37 raeburn Exp $
+# $Id: lonpickcourse.pm,v 1.73.2.2 2008/07/01 05:26:04 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -228,14 +228,23 @@ sub display_matched_courses {
                  $menuchk = ' checked="checked" ';
             }
             $r->print(
+                '<table class="LC_pick_box">'.
+                '<tr class="LC_pick_box_row">'.
+                '<td class="LC_pick_box_title" rowspan="2">'.&mt('Action').'</td>'.
+                '<td class="LC_evenrow_value">'.
                 '<span class="LC_nobreak"><label>'.
                 '<input type="radio" name="phase" value="ccrole"'.$ccrolechk.'/>'.
                 '&nbsp;'.&mt('Enter the course with the role of [_1].',$cctitle).
-                '</label>'.('&nbsp;'x3).'</span><br />'.
+                '</label>'.('&nbsp;'x3).'</span>'.
+                '</td></tr>'.
+                '<tr class="LC_pick_box_row">'.
+                '<td class="LC_oddrow_value">'.
                 '<span class="LC_nobreak"><label>'.
                 '<input type="radio" name="phase" value="menu"'.$menuchk.'/>&nbsp;'.
                 &mt('View or modify course settings which only a [_1] may modify.',$dctitle).
-                '</label></span><br /><br />');
+                '</label></span>'.
+                '</td></tr></table>'.
+                '<br />');
         }
     }
     my %by_descrip;
@@ -251,6 +260,7 @@ sub display_matched_courses {
         my $description = $descr;
         push (@{$by_descrip{$description}}, $course);
     }
+ 
     if ($numcourses > 1 && $multiple) {
         $r->print('<input type="button" value="check all"
                   onclick="javascript:checkAll(document.courselist.course_id)" />
@@ -258,8 +268,22 @@ sub display_matched_courses {
                   onclick="javascript:uncheckAll(document.courselist.course_id)" />
                   <br /><br />');
     }
+
+    if (%courses) {
+        $r->print(&Apache::loncommon::start_data_table());
+        $r->print(&Apache::loncommon::start_data_table_header_row());
+        $r->print('<th>'.&mt('Select').'</th>'
+                 .'<th>'.&mt('Course Description').'</th>'
+                 .'<th>'.&mt('Domain').'</th>'
+                 .'<th>'.&mt('Course Code').'</th>'
+                 .'<th>'.&mt('Owner/Co-owner(s)').'</th>'
+#                 .'<th>'.&mt('Type').'</th>'
+                 );
+        $r->print(&Apache::loncommon::end_data_table_header_row());
+    }
     foreach my $description (sort { lc($a) cmp lc($b) } (keys(%by_descrip))) {
         foreach my $course (@{$by_descrip{$description}}) {
+            $r->print(&Apache::loncommon::start_data_table_row());
             my $cleandesc=&HTML::Entities::encode($description,'<>&"');
             $cleandesc=~s/'/\\'/g;
             my ($cdom,$cnum)=split(/\_/,$course);
@@ -279,26 +303,37 @@ sub display_matched_courses {
                 ($descr,$instcode,$singleowner,$ttype)=split(/:/,$courses{$course});
                 push(@owners,&unescape($singleowner));
             }
-            my $owner = join(', ',@owners);
-            $r->print(&course_chooser($multiple,$cdom,$cnum,$cleandesc));
-            $r->print($description.' ('.
-                      (&Apache::lonnet::domain($cdom,'description')?
-                       &Apache::lonnet::domain($cdom,'description'):$cdom).")");
+            my $ownerstr = join(', ',@owners);
+            $r->print('<td>'.&course_chooser($multiple,$cdom,$cnum,$cleandesc).'</td>');
+            $r->print('<td>'.$description.'</td>');
+            $r->print('<td>');
+            $r->print(&Apache::lonnet::domain($cdom,'description')?
+                      $cdom.' ('.&Apache::lonnet::domain($cdom,'description').')':$cdom);
+            $r->print('</td>');
+            $r->print('<td>');
             if ($instcode ne '') {
-                $r->print(" - ".&unescape($instcode));
-            }
-            if (@owners > 1) {
-                $r->print(', '.&mt('owners').' - ',join(', ',@owners)); 
-            } elsif (@owners == 1) {
-                $r->print(', '.&mt('owner').' - '.$owner);
-            }
-            if ($ttype ne '') {
-                $r->print(' ('.&unescape($ttype).')');
+                $r->print(&unescape($instcode));
+            } else {
+                $r->print('&nbsp;');
             }
+            $r->print('</td>');
+            $r->print('<td>'.$ownerstr.'</td>');
+#            $r->print('<td>');
+#            if ($ttype ne '') {
+#                $r->print(&mt(&unescape($ttype)));
+#            } else {
+#                $r->print('&nbsp;');
+#            }
+#            $r->print('</td>');
             if ($multiple) { $r->print("</label>\n"); }
-            $r->print("<br />\n");
+            $r->print(&Apache::loncommon::end_data_table_row());
+            # $r->print("<br />\n");
         }
     }
+    if (%courses) {
+        $r->print(&Apache::loncommon::end_data_table());
+    }
+
     if (!%courses) {
         $r->print(&mt('None found'));
     } elsif ($multiple) {
@@ -417,8 +452,8 @@ sub build_filters {
                 $list->{'instcodefilter'}.'" />';
     }
     foreach my $posstype ('Course','Non-standard Course') {
-        $typeselectform.='<option value="'.$posstype.'" "'.
-            ($posstype eq $type ? 'selected="selected" ' : ''). ">$posstype</option>\n";
+        $typeselectform.='<option value="'.$posstype.'"'.
+            ($posstype eq $type ? ' selected="selected" ' : ''). ">".&mt($posstype)."</option>\n";
     }
     $typeselectform.="</select>";
     my $output = qq|
@@ -483,7 +518,7 @@ sub search_courses {
     my ($r,$type,$onlyown,$filter) = @_;
     my %courses;
     if (!$onlyown) {
-        $r->print(&mt('Searching').' ...<br />&nbsp;<br />');
+        $r->print(&mt('Searching ...').'<br />&nbsp;<br />');
         $r->rflush();
         if (($filter->{'ownerfilter'} ne '') ||
             ($filter->{'ownerdomfilter'} ne '')) {
@@ -523,7 +558,7 @@ sub course_chooser {
     if ($multiple) {
         $output = '<label><input type="checkbox" name="course_id" value="'.$cdom.'_'.$cnum.'" />'."\n";
     } else {
-        $output = '<input type="button" value="Select" onClick="gochoose('.
+        $output = '<input type="button" value="'.&mt('Select').'" onClick="gochoose('.
                   "'".$cnum."','".$cdom."','".$cleandesc."')".'" />'."\n";
     }
     return $output;
