@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Syllabus
 #
-# $Id: lonsyllabus.pm,v 1.66 2008/07/17 12:01:46 raeburn Exp $
+# $Id: lonsyllabus.pm,v 1.67 2008/08/25 14:50:01 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -198,8 +198,8 @@ ENDSCRIPT
                     ($env{'user.domain'} eq '') || ($env{'user.domain'} eq 'public')) {
 		    $r->print(' '.$courseperson);
                 } else {
-                    $r->print(' '.&Apache::loncommon::aboutmewrapper($courseperson),
-                              $puname,$pudom);
+                    $r->print(' '.&Apache::loncommon::aboutmewrapper($courseperson,
+                              $puname,$pudom));
                 }
 	    } else {
 		$r->print(' '.&Apache::loncommon::plainname($puname,
