@@ -1,5 +1,5 @@
 #
-# $Id: lonwhatsnew.pm,v 1.79 2008/07/09 15:16:14 raeburn Exp $
+# $Id: lonwhatsnew.pm,v 1.80 2008/08/26 01:12:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -462,9 +462,9 @@ sub display_actions_box {
     }
 
     $headings{'abovethreshold'} = 
-	&mt('Problems with av. attempts &ge; [_1] or deg. difficulty &ge; [_2] <br /> and total number of '.$stulabel{$crstype}.' with submissions &ge; [_3]',
+	&mt('(Problems with av. attempts &ge; [_1] or deg. difficulty &ge; [_2]) [_3] and total number of '.$stulabel{$crstype}.' with submissions &ge; [_4]',
 	    $threshold{'av_attempts'},$threshold{'degdiff'},
-	    $threshold{'numstudents'});
+	    '<br />',$threshold{'numstudents'});
 
     my @actionorder = ('handgrading','haserrors','abovethreshold','versionchanges','coursediscussion','coursenormalmail','coursecritmail','newroles','oldroles');
 
