@@ -58,7 +58,7 @@ sub handler {
     my $uname = &unescape($env{'form.uname'});
     my $udom = $env{'form.udom'};
     my $token = $env{'form.token'};
-    $r->print(&mt('<h3>Reset forgotten LON-CAPA password</h3>'));
+    $r->print(&mt('<h3>'.&mt('Reset forgotten LON-CAPA password').'</h3>'));
     my $output;
     if ($token) {
         $output = &reset_passwd($r,$token,$contact_name,$contact_email);
@@ -122,7 +122,11 @@ sub get_uname {
                                          proc => 'Proceed');
 
     my $msg = &mt('If you use the same account for other campus services besides LON-CAPA, (e.g., e-mail, course registration, etc.), a separate centrally managed mechanism likely exists to reset a password.  However, if your account is used for just LON-CAPA access you will probably be able to reset a password from this page.');
-    $msg .= '<br /><br />'.&mt('Three conditions must be met:<ul><li>An e-mail address must have previously been associated with your LON-CAPA username.</li><li>You must be able to access e-mail sent to that address.</li><li>Your account must be of a type for which LON-CAPA can reset a password.</ul>');
+    $msg .= '<br /><br />'.&mt('Three conditions must be met:')
+           .'<ul><li>'.&mt('An e-mail address must have previously been associated with your LON-CAPA username.').'</li>'
+           .'<li>'.&mt('You must be able to access e-mail sent to that address.').'</li>'
+           .'<li>'.&mt('Your LON-CAPA account must be of a type for which LON-CAPA can reset a password.')
+           .'</ul>';
     $msg .= qq|
 <form name="forgotpw" method="post">
 <table>
@@ -201,7 +205,8 @@ sub invalid_state {
     my ($error,$domdesc,$contact_name,$contact_email) = @_;
     my $msg;
     if ($error eq 'invalid') {
-        $msg = &mt('The username you provided was not verified as a valid username in the LON-CAPA system for the [_1] domain.',$domdesc).&mt(' Please <a href="javascript:history.go(-1)"><u>go back</u></a> and try again.');
+        $msg = &mt('The username you provided was not verified as a valid username in the LON-CAPA system for the [_1] domain.',$domdesc)
+              .' '.&mt('Please [_1]go back[_2] and try again.','<a href="javascript:history.go(-1)"><u>','</u></a>');
     } else {
         if ($error eq 'baduseremail') {
             $msg = &mt('The e-mail address you provided does not appear to be a valid address.');
@@ -214,9 +219,10 @@ sub invalid_state {
         }
         if ($contact_email ne '') {
             my $escuri = &HTML::Entities::encode('/adm/resetpw','&<>"');
-            $msg .= '<br />'.&mt(' You may wish to contact the <a href="/adm/helpdesk?origurl=[_1]">LON-CAPA helpdesk</a> for the [_2] domain.',$escuri,$domdesc);
+            $msg .= '<br /> '.&mt('You may wish to contact the [_1]LON-CAPA helpdesk[_2] for the [_3] domain.'
+                                 ,'<a href="/adm/helpdesk?origurl='.$escuri.'">','</a>',$domdesc);
         } else {
-            $msg .= '<br />'.&mt(' You may wish to send an e-mail to the server administrator: [_1] for the [_2] domain.',$Apache::lonnet::perlvar{'AdminEmail'},$domdesc);
+            $msg .= '<br /> '.&mt('You may wish to send an e-mail to the server administrator: [_1] for the [_2] domain.',$Apache::lonnet::perlvar{'AdminEmail'},$domdesc);
         }
     }
     return $msg;
