@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for requesting to have slots added to a students record
 #
-# $Id: slotrequest.pm,v 1.80 2007/09/21 22:37:23 albertel Exp $
+# $Id: slotrequest.pm,v 1.81 2008/01/14 14:32:30 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -473,8 +473,9 @@ sub release_reservation {
     }
 
     # get parameter string, check for existance, rebuild string with the slot
-    my @slots = split(/:/,&Apache::lonnet::EXT("resource.0.availablestudent",
-					       $symb,$udom,$uname));
+    my $student = &Apache::lonnet::EXT("resource.0.availablestudent",
+                                       $symb,$udom,$uname);
+    my @slots = split(/:/,$student);
 
     my @new_slots;
     foreach my $exist_slot (@slots) {
