@@ -1,5 +1,5 @@
 #
-# $Id: Spreadsheet.pm,v 1.77 2007/01/23 18:22:47 albertel Exp $
+# $Id: Spreadsheet.pm,v 1.78 2008/03/12 02:45:27 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -210,8 +210,8 @@ sub make_default {
             {'spreadsheet_default_'.$self->{'type'} => $self->filename()},
                                      $self->{'cdom'},$self->{'cnum'});
     return $result if ($result ne 'ok');
-    &Apache::lonnet::appenv('course.'.$self->{'cid'}.'.spreadsheet_default_'.
-			    $self->{'type'} => $self->filename());
+    &Apache::lonnet::appenv({'course.'.$self->{'cid'}.'.spreadsheet_default_'.
+			    $self->{'type'} => $self->filename()});
     my $symb = $self->{'symb'};
     $symb = '' if (! defined($symb));
     &Apache::lonnet::expirespread('','',$self->{'type'},$symb);    
@@ -1809,8 +1809,8 @@ sub save {
                                 {'spreadsheet_default_'.$stype => $filename },
                                           $cdom,$cnum);
             return $reply if ($reply ne 'ok');
-	    &Apache::lonnet::appenv('course.'.$self->{'cid'}.'.spreadsheet_default_'.
-				    $self->{'type'} => $self->filename());
+	    &Apache::lonnet::appenv({'course.'.$self->{'cid'}.'.spreadsheet_default_'.
+				    $self->{'type'} => $self->filename()});
         } 
 	if ($self->{'type'} eq 'studentcalc') {
 	    &Apache::lonnet::expirespread('','','studentcalc','');
