@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Localization routines
 #
-# $Id: lonlocal.pm,v 1.43 2008/01/29 13:26:09 www Exp $
+# $Id: lonlocal.pm,v 1.47 2008/07/02 21:31:32 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -165,6 +165,7 @@ use Apache::localize;
 use locale;
 use POSIX qw(locale_h strftime);
 use DateTime();
+use DateTime::TimeZone;
 
 require Exporter;
 
@@ -182,7 +183,15 @@ sub mt (@) {
 #    print LOG (@_[0]."\n");
 #    close(LOG);
     if ($lh) {
-	return $lh->maketext(@_);
+        if ($_[0] eq '') {
+            if (wantarray) {
+                return @_;
+            } else {
+                return $_[0];
+            }
+        } else {
+            return $lh->maketext(@_);
+        }
     } else {
 	if (wantarray) {
 	    return @_;
@@ -259,9 +268,22 @@ sub get_language_handle {
 
 # ========================================================== Localize localtime
 sub gettimezone {
-    my ($time) = @_;
+    my $timezone; 
     if ($Apache::lonnet::env{'course.'.$Apache::lonnet::env{'request.course.id'}.'.timezone'}) {
-	return $Apache::lonnet::env{'course.'.$Apache::lonnet::env{'request.course.id'}.'.timezone'};
+        $timezone = $Apache::lonnet::env{'course.'.$Apache::lonnet::env{'request.course.id'}.'.timezone'};    
+    } elsif ($Apache::lonnet::env{'request.course.id'} ne '') {
+        my $cdom = $Apache::lonnet::env{'course.'.$Apache::lonnet::env{'request.course.id'}.'.domain'};
+        if ($cdom ne '') {
+            my %domdefaults = &Apache::lonnet::get_domain_defaults($cdom);
+            if ($domdefaults{'timezone_def'} ne '') {
+                $timezone = $domdefaults{'timezone_def'};
+            }
+        }
+    }
+    if ($timezone ne '') {
+        if (DateTime::TimeZone->is_valid_name($timezone)) {
+            return $timezone;
+        }
     }
     return 'local';
 }
@@ -271,6 +293,14 @@ sub locallocaltime {
     if (!defined($thistime) || $thistime eq '') {
 	return &mt('Never');
     }
+    if (($thistime < 0) || ($thistime eq 'NaN')) {
+        &Apache::lonnet::logthis("Unexpected time (negative or NaN) '$thistime' passed to lonlocal::locallocaltime");  
+        return &mt('Never');
+    }
+    if ($thistime !~ /^\d+$/) {
+        &Apache::lonnet::logthis("Unexpected non-numeric time '$thistime' passed to lonlocal::locallocaltime");
+        return &mt('Never');
+    }
 
     my $dt = DateTime->from_epoch(epoch => $thistime)
                      ->set_time_zone(&gettimezone());
