@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # URL translation for encrypted filenames
 #
-# $Id: lonenc.pm,v 1.22 2007/10/05 18:33:29 albertel Exp $
+# $Id: lonenc.pm,v 1.23 2008/03/17 09:51:40 foxr Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -34,6 +34,17 @@ use Crypt::IDEA;
 use Time::HiRes qw(gettimeofday);
 use LONCAPA;
  
+
+#
+#  If a module makes multiple SSI calls and some of the ssi calls result in a
+#  resource for an encoded URL, and this can be done in an unprivileged role,
+#  there must be a mechanism t oreset the 'request.enc' environment variable.
+#  This sub centralizes that mechanism:
+#
+sub reset_enc {
+    $env{'request.enc'} = 0;
+}
+
 sub encryptseed {
     my ($cid) = @_;
     if (!defined($cid)) {
