@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # TeX Conversion Module
 #
-# $Id: lontexconvert.pm,v 1.87 2008/02/06 10:16:00 foxr Exp $
+# $Id: lontexconvert.pm,v 1.88 2008/07/18 13:09:33 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -219,7 +219,9 @@ sub jsMath_converted {
 
 sub tex_engine {
     if (exists($env{'form.texengine'})) {
-	return $env{'form.texengine'};
+	if ($env{'form.texengine'} ne '') {
+            return $env{'form.texengine'};
+        }
     }    
     if ($env{'request.course.id'}
 	&& exists($env{'course.'.$env{'request.course.id'}.'.texengine'})) {
