@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # XML Parser Module 
 #
-# $Id: lonxml.pm,v 1.481 2008/06/25 12:00:37 raeburn Exp $
+# $Id: lonxml.pm,v 1.484 2008/08/08 16:50:39 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -361,8 +361,8 @@ sub xmlparse {
 				   $safeeval,\%style_for_target,1);
 
  if (@stack) {
-     &warning("At end of file some tags were still left unclosed, ".
-	      '<tt>&lt;'.join('&gt;</tt>, <tt>&lt;',reverse(@stack)).
+     &warning(&mt('At end of file some tags were still left unclosed:').
+	      ' <tt>&lt;'.join('&gt;</tt>, <tt>&lt;',reverse(@stack)).
 	      '&gt;</tt>');
  }
  if ($env{'request.uri'}) {
@@ -486,10 +486,10 @@ sub inner_xmlparse {
 	    while ($token->[1] ne $$stack['-1'] && ($#$stack > -1)) {
 		my $lasttag=$$stack[-1];
 		if ($token->[1] =~ /^\Q$lasttag\E$/i) {
-		    &Apache::lonxml::warning('Using tag &lt;/'.$token->[1].'&gt; on line '.$token->[3].' as end tag to &lt;'.$$stack[-1].'&gt;');
+		    &Apache::lonxml::warning(&mt('Using tag [_1] on line [_2] as end tag to [_3]','&lt;/'.$token->[1].'&gt;','.$token->[3].','&lt;'.$$stack[-1].'&gt;'));
 		    last;
 		} else {
-		    &Apache::lonxml::warning('Found tag &lt;/'.$token->[1].'&gt; on line '.$token->[3].' when looking for &lt;/'.$$stack[-1].'&gt; in file');
+                    &Apache::lonxml::warning(&mt('Found tag [_1] on line [_2] when looking for [_3] in file.','&lt;/'.$token->[1].'&gt;',$token->[3],'&lt;/'.$$stack[-1].'&gt;'));
 		    &end_tag($stack,$parstack,$token);
 		}
 	    }
@@ -1451,7 +1451,7 @@ sub storefile {
         $fh->close();
         return 1;
     } else {
-	&warning("Unable to save file $file");
+	&warning(&mt('Unable to save file [_1]','<tt>'.$file.'</tt>'));
 	return 0;
     }
 }
@@ -1519,7 +1519,7 @@ sub renderingoptions {
        &mt('Math Rendering:').' '.
        &Apache::loncommon::select_form($env{'form.texengine'},'texengine',
                                                      ('' => '',
-                                                      'tth' => 'tth (Tex-to-HTML)',
+                                                      'tth' => 'tth (TeX to HTML)',
                                                       'jsMath' => 'jsMath',
                                                       'mimetex' => 'mimetex (Convert to Images)')).'
      </span>';
@@ -1844,8 +1844,10 @@ sub error {
     if ( &show_error_warn_msg() ) {
 	# If printing in construction space, put the error inside <pre></pre>
 	push(@Apache::lonxml::error_messages,
-	     $Apache::lonxml::warnings_error_header.
-             "<b>".&mt('ERROR:')."</b>".join("<br />\n",@errors)."<br />\n");
+	     $Apache::lonxml::warnings_error_header
+             .'<div class="LC_error">'
+             .'<b>'.&mt('ERROR:').' </b>'.join("<br />\n",@errors)
+             ."</div>\n");
 	$Apache::lonxml::warnings_error_header='';
     } else {
 	my $errormsg;
@@ -1906,8 +1908,11 @@ sub warning {
     if ($env{'form.grade_target'} ne 'tex') {
 	if ( &show_error_warn_msg() ) {
 	    push(@Apache::lonxml::warning_messages,
-		 $Apache::lonxml::warnings_error_header.
-		 "<b>W</b>ARNING<b>:</b>".join('<br />',@_)."<br />\n");
+		 $Apache::lonxml::warnings_error_header
+                .'<div class="LC_warning">'
+                .&mt('[_1]W[_2]ARNING','<b>','</b>')."<b>:</b> ".join('<br />',@_)
+                ."</div>\n"
+                );
 	    $Apache::lonxml::warnings_error_header='';
 	}
     }
