@@ -2,7 +2,7 @@
 #
 # Page flip handler
 #
-# $Id: lonpageflip.pm,v 1.74 2006/10/20 22:04:16 albertel Exp $
+# $Id: lonpageflip.pm,v 1.75 2008/03/12 02:45:50 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -444,7 +444,7 @@ sub handler {
 			   $redirectsymb='';
                         }
                      }
-                     &Apache::lonnet::appenv('user.criticalcheck.time'=>time);
+                     &Apache::lonnet::appenv({'user.criticalcheck.time'=>time});
 		  }
 
 		  &Apache::loncommon::content_type($r,'text/html');
